{% load static %}
{% load i18n %}
{% load navactive %}

<div class="navbar navbar-default">
    <div class="container-fluid">
        <div class="navbar-header">
            <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                <span class="sr-only">{% trans "Toggle navigation" %}</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
            <a class="navbar-brand" href="{% url 'evictionsplit:index' %}">Eviction activity</a>
        </div>
        <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
            <ul class="nav navbar-nav">
                <li class="{% navactive request 'evictionsplit:index' %}">
                    <a href="{% url 'evictionsplit:index' %}">Home</a>
                </li>
                <li class="{% navactive request 'evictionsplit:list' %}">
                    <a href="{% url 'evictionsplit:list' %}">Active evictions</a>
                </li>
            </ul>

        {% if user_has_manager_permission %}
            <div class="nav navbar-nav navbar-right">
                <li class="{% navactive request 'evictionsplit:manage' %}">
                    <a href="{% url 'evictionsplit:manage' %}">Management</a>
                </li>
            </div>
        {% endif %}

        </div>
    </div>
</div>
